@@ -33,7 +33,7 @@ class LiveTradingSystem:
                  data_source: str = "demo", granularity: str = "1m", lookback_override: int | None = None,
                  enable_trading: bool = False, multi_strategy_config: str | None = None,
                  broker_type: str | None = None, paper_trading: bool = True, engine_type: str | None = None,
-                 position_sizer=None):
+                 position_sizer=None, allocation: float = 0.0):
         """
         Initialize live trading system
         
@@ -66,8 +66,8 @@ class LiveTradingSystem:
         # Load configuration
         self.data_config, self.trading_config = load_config()
 
-        # Initialize statistics manager with default cash (will be updated from broker if available)
-        self.statistics_manager = StatisticsManager(initial_cash=100000.0)
+        # Initialize statistics manager with default cash and allocation (will be updated from broker if available)
+        self.statistics_manager = StatisticsManager(initial_cash=100000.0, allocation=allocation)
 
         # Initialize strategy components
         self._initialize_strategies(strategy_path, multi_strategy_config)
@@ -291,11 +291,11 @@ class LiveTradingSystem:
 
         # Log system configuration
         strategy_info = self.trading_processor.get_strategy_info()
-        logger.info(f"Strategy: {strategy_info}")
-        logger.info(f"Symbols: {', '.join(self.symbols)}")
-        logger.info(f"Data Source: {self.data_source}")
-        logger.info(f"Granularity: {self.granularity}")
-        logger.info(f"Lookback Period: {self.lookback_period} bars")
+        logger.debug(f"Strategy: {strategy_info}")
+        logger.debug(f"Symbols: {', '.join(self.symbols)}")
+        logger.debug(f"Data Source: {self.data_source}")
+        logger.debug(f"Granularity: {self.granularity}")
+        logger.debug(f"Lookback Period: {self.lookback_period} bars")
 
         # Display startup banner
         self.display_manager.display_startup_banner(
@@ -319,7 +319,7 @@ class LiveTradingSystem:
         try:
             granularity_obj = parse_granularity(self.granularity)
             cycle_interval = granularity_obj.to_seconds()
-            logger.info(f"Trading cycle interval set to {cycle_interval} seconds based on granularity {self.granularity}")
+            logger.debug(f"Trading cycle interval set to {cycle_interval} seconds based on granularity {self.granularity}")
         except Exception as e:
             logger.warning(f"Could not parse granularity {self.granularity}: {e}. Using default 5-second interval")
             cycle_interval = 999_999
@@ -429,7 +429,7 @@ class LiveTradingSystem:
                                 success = False
 
                             if success:
-                                logger.info(f"✅ Executed {signal.signal.value} for {symbol} [{strategy_id}]")
+                                logger.debug(f"✅ Executed {signal.signal.value} for {symbol} [{strategy_id}]")
                             else:
                                 logger.warning(f"❌ Failed to execute {signal.signal.value} for {symbol} [{strategy_id}]")
         else:
@@ -447,7 +447,7 @@ class LiveTradingSystem:
                         success = False
 
                     if success:
-                        logger.info(f"✅ Executed {signal.signal.value} for {symbol}")
+                        logger.debug(f"✅ Executed {signal.signal.value} for {symbol}")
                     else:
                         logger.warning(f"❌ Failed to execute {signal.signal.value} for {symbol}")
 
